pub struct AddTeamMember;Trait Implementations
Sourceimpl GraphQLQuery for AddTeamMember
impl GraphQLQuery for AddTeamMember
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for AddTeamMember
impl RefUnwindSafe for AddTeamMember
impl Send for AddTeamMember
impl Sync for AddTeamMember
impl Unpin for AddTeamMember
impl UnsafeUnpin for AddTeamMember
impl UnwindSafe for AddTeamMember