pub struct CreateDatasetFromMultipart;Trait Implementations
Sourceimpl GraphQLQuery for CreateDatasetFromMultipart
impl GraphQLQuery for CreateDatasetFromMultipart
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CreateDatasetFromMultipart
impl RefUnwindSafe for CreateDatasetFromMultipart
impl Send for CreateDatasetFromMultipart
impl Sync for CreateDatasetFromMultipart
impl Unpin for CreateDatasetFromMultipart
impl UnsafeUnpin for CreateDatasetFromMultipart
impl UnwindSafe for CreateDatasetFromMultipart