pub struct CreateTeam;Trait Implementations
Sourceimpl GraphQLQuery for CreateTeam
impl GraphQLQuery for CreateTeam
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CreateTeam
impl RefUnwindSafe for CreateTeam
impl Send for CreateTeam
impl Sync for CreateTeam
impl Unpin for CreateTeam
impl UnsafeUnpin for CreateTeam
impl UnwindSafe for CreateTeam