pub struct CreateUser;Trait Implementations
Sourceimpl GraphQLQuery for CreateUser
impl GraphQLQuery for CreateUser
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CreateUser
impl RefUnwindSafe for CreateUser
impl Send for CreateUser
impl Sync for CreateUser
impl Unpin for CreateUser
impl UnsafeUnpin for CreateUser
impl UnwindSafe for CreateUser