pub struct DeleteUser;Trait Implementations
Sourceimpl GraphQLQuery for DeleteUser
impl GraphQLQuery for DeleteUser
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for DeleteUser
impl RefUnwindSafe for DeleteUser
impl Send for DeleteUser
impl Sync for DeleteUser
impl Unpin for DeleteUser
impl UnsafeUnpin for DeleteUser
impl UnwindSafe for DeleteUser