pub struct GetArtifact;Trait Implementations
Sourceimpl GraphQLQuery for GetArtifact
impl GraphQLQuery for GetArtifact
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetArtifact
impl RefUnwindSafe for GetArtifact
impl Send for GetArtifact
impl Sync for GetArtifact
impl Unpin for GetArtifact
impl UnsafeUnpin for GetArtifact
impl UnwindSafe for GetArtifact