pub struct GetCustomRecipes;Trait Implementations
Sourceimpl GraphQLQuery for GetCustomRecipes
impl GraphQLQuery for GetCustomRecipes
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetCustomRecipes
impl RefUnwindSafe for GetCustomRecipes
impl Send for GetCustomRecipes
impl Sync for GetCustomRecipes
impl Unpin for GetCustomRecipes
impl UnsafeUnpin for GetCustomRecipes
impl UnwindSafe for GetCustomRecipes