pub struct GetDataset;Trait Implementations
Sourceimpl GraphQLQuery for GetDataset
impl GraphQLQuery for GetDataset
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetDataset
impl RefUnwindSafe for GetDataset
impl Send for GetDataset
impl Sync for GetDataset
impl Unpin for GetDataset
impl UnsafeUnpin for GetDataset
impl UnwindSafe for GetDataset