pub struct GetGrader;Trait Implementations
Sourceimpl GraphQLQuery for GetGrader
impl GraphQLQuery for GetGrader
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetGrader
impl RefUnwindSafe for GetGrader
impl Send for GetGrader
impl Sync for GetGrader
impl Unpin for GetGrader
impl UnsafeUnpin for GetGrader
impl UnwindSafe for GetGrader