pub struct GetJob;Trait Implementations
Sourceimpl GraphQLQuery for GetJob
impl GraphQLQuery for GetJob
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetJob
impl RefUnwindSafe for GetJob
impl Send for GetJob
impl Sync for GetJob
impl Unpin for GetJob
impl UnsafeUnpin for GetJob
impl UnwindSafe for GetJob