pub struct GetModelConfig;Trait Implementations
Sourceimpl GraphQLQuery for GetModelConfig
impl GraphQLQuery for GetModelConfig
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for GetModelConfig
impl RefUnwindSafe for GetModelConfig
impl Send for GetModelConfig
impl Sync for GetModelConfig
impl Unpin for GetModelConfig
impl UnsafeUnpin for GetModelConfig
impl UnwindSafe for GetModelConfig