pub struct ListAllModels;Trait Implementations
Sourceimpl GraphQLQuery for ListAllModels
impl GraphQLQuery for ListAllModels
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListAllModels
impl RefUnwindSafe for ListAllModels
impl Send for ListAllModels
impl Sync for ListAllModels
impl Unpin for ListAllModels
impl UnsafeUnpin for ListAllModels
impl UnwindSafe for ListAllModels