pub struct ListComputePools;Trait Implementations
Sourceimpl GraphQLQuery for ListComputePools
impl GraphQLQuery for ListComputePools
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListComputePools
impl RefUnwindSafe for ListComputePools
impl Send for ListComputePools
impl Sync for ListComputePools
impl Unpin for ListComputePools
impl UnwindSafe for ListComputePools