pub struct ListJobs;Trait Implementations
Sourceimpl GraphQLQuery for ListJobs
impl GraphQLQuery for ListJobs
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListJobs
impl RefUnwindSafe for ListJobs
impl Send for ListJobs
impl Sync for ListJobs
impl Unpin for ListJobs
impl UnsafeUnpin for ListJobs
impl UnwindSafe for ListJobs