pub struct ListModels;Trait Implementations
Sourceimpl GraphQLQuery for ListModels
impl GraphQLQuery for ListModels
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListModels
impl RefUnwindSafe for ListModels
impl Send for ListModels
impl Sync for ListModels
impl Unpin for ListModels
impl UnsafeUnpin for ListModels
impl UnwindSafe for ListModels