pub struct ListProjects;Trait Implementations
Sourceimpl GraphQLQuery for ListProjects
impl GraphQLQuery for ListProjects
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListProjects
impl RefUnwindSafe for ListProjects
impl Send for ListProjects
impl Sync for ListProjects
impl Unpin for ListProjects
impl UnsafeUnpin for ListProjects
impl UnwindSafe for ListProjects