pub struct ListRoles;Trait Implementations
Sourceimpl GraphQLQuery for ListRoles
impl GraphQLQuery for ListRoles
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListRoles
impl RefUnwindSafe for ListRoles
impl Send for ListRoles
impl Sync for ListRoles
impl Unpin for ListRoles
impl UnsafeUnpin for ListRoles
impl UnwindSafe for ListRoles