pub struct ListTeams;Trait Implementations
Sourceimpl GraphQLQuery for ListTeams
impl GraphQLQuery for ListTeams
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListTeams
impl RefUnwindSafe for ListTeams
impl Send for ListTeams
impl Sync for ListTeams
impl Unpin for ListTeams
impl UnsafeUnpin for ListTeams
impl UnwindSafe for ListTeams