pub struct ListUseCases;Trait Implementations
Sourceimpl GraphQLQuery for ListUseCases
impl GraphQLQuery for ListUseCases
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for ListUseCases
impl RefUnwindSafe for ListUseCases
impl Send for ListUseCases
impl Sync for ListUseCases
impl Unpin for ListUseCases
impl UnwindSafe for ListUseCases