pub struct PublishCustomRecipe;Trait Implementations
Sourceimpl GraphQLQuery for PublishCustomRecipe
impl GraphQLQuery for PublishCustomRecipe
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for PublishCustomRecipe
impl RefUnwindSafe for PublishCustomRecipe
impl Send for PublishCustomRecipe
impl Sync for PublishCustomRecipe
impl Unpin for PublishCustomRecipe
impl UnsafeUnpin for PublishCustomRecipe
impl UnwindSafe for PublishCustomRecipe