pub struct RemoveTeamMember;Trait Implementations
Sourceimpl GraphQLQuery for RemoveTeamMember
impl GraphQLQuery for RemoveTeamMember
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for RemoveTeamMember
impl RefUnwindSafe for RemoveTeamMember
impl Send for RemoveTeamMember
impl Sync for RemoveTeamMember
impl Unpin for RemoveTeamMember
impl UnsafeUnpin for RemoveTeamMember
impl UnwindSafe for RemoveTeamMember