pub struct RunCustomRecipe;Trait Implementations
Sourceimpl GraphQLQuery for RunCustomRecipe
impl GraphQLQuery for RunCustomRecipe
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for RunCustomRecipe
impl RefUnwindSafe for RunCustomRecipe
impl Send for RunCustomRecipe
impl Sync for RunCustomRecipe
impl Unpin for RunCustomRecipe
impl UnsafeUnpin for RunCustomRecipe
impl UnwindSafe for RunCustomRecipe