pub struct UpdateCustomRecipe;Trait Implementations
Sourceimpl GraphQLQuery for UpdateCustomRecipe
impl GraphQLQuery for UpdateCustomRecipe
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UpdateCustomRecipe
impl RefUnwindSafe for UpdateCustomRecipe
impl Send for UpdateCustomRecipe
impl Sync for UpdateCustomRecipe
impl Unpin for UpdateCustomRecipe
impl UnsafeUnpin for UpdateCustomRecipe
impl UnwindSafe for UpdateCustomRecipe