pub struct UpdateRole;Trait Implementations
Sourceimpl GraphQLQuery for UpdateRole
impl GraphQLQuery for UpdateRole
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UpdateRole
impl RefUnwindSafe for UpdateRole
impl Send for UpdateRole
impl Sync for UpdateRole
impl Unpin for UpdateRole
impl UnsafeUnpin for UpdateRole
impl UnwindSafe for UpdateRole