pub struct UploadDataset;Trait Implementations
Sourceimpl GraphQLQuery for UploadDataset
impl GraphQLQuery for UploadDataset
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for UploadDataset
impl RefUnwindSafe for UploadDataset
impl Send for UploadDataset
impl Sync for UploadDataset
impl Unpin for UploadDataset
impl UnsafeUnpin for UploadDataset
impl UnwindSafe for UploadDataset