pub struct AdaptiveClient { /* private fields */ }Implementations
Sourceimpl AdaptiveClient
impl AdaptiveClient
pub fn new(api_base_url: Url, auth_token: String) -> Self
pub async fn list_recipes( &self, project: &str, ) -> Result<Vec<GetCustomRecipesCustomRecipes>, AdaptiveError>
pub async fn get_job(&self, job_id: Uuid) -> Result<GetJobJob, AdaptiveError>
pub async fn upload_dataset<P: AsRef<Path>>( &self, project: &str, name: &str, dataset: P, ) -> Result<UploadDatasetCreateDataset, AdaptiveError>
pub async fn publish_recipe<P: AsRef<Path>>( &self, project: &str, name: &str, key: &str, recipe: P, ) -> Result<PublishCustomRecipeCreateCustomRecipe, AdaptiveError>
pub async fn update_recipe<P: AsRef<Path>>( &self, project: &str, id: &str, name: Option<String>, description: Option<String>, labels: Option<Vec<LabelInput>>, recipe_file: Option<P>, ) -> Result<UpdateCustomRecipeUpdateCustomRecipe, AdaptiveError>
pub async fn run_recipe( &self, project: &str, recipe_id: &str, parameters: Map<String, Value>, name: Option<String>, compute_pool: Option<String>, num_gpus: u32, use_experimental_runner: bool, ) -> Result<RunCustomRecipeCreateJob, AdaptiveError>
pub async fn list_jobs( &self, project: Option<String>, ) -> Result<Vec<ListJobsJobsNodes>, AdaptiveError>
pub async fn cancel_job( &self, job_id: Uuid, ) -> Result<CancelJobCancelJob, AdaptiveError>
pub async fn update_job_progress( &self, job_id: Uuid, event: JobProgressEventInput, ) -> Result<UpdateJobProgressUpdateJobProgress, AdaptiveError>
pub async fn list_models( &self, project: String, ) -> Result<Vec<ListModelsProjectModelServices>, AdaptiveError>
pub async fn list_all_models( &self, ) -> Result<Vec<ListAllModelsModels>, AdaptiveError>
pub async fn list_projects( &self, ) -> Result<Vec<ListProjectsProjects>, AdaptiveError>
pub async fn list_pools( &self, ) -> Result<Vec<ListComputePoolsComputePools>, AdaptiveError>
pub async fn list_roles(&self) -> Result<Vec<ListRolesRoles>, AdaptiveError>
pub async fn create_role( &self, name: &str, key: Option<&str>, permissions: Vec<String>, ) -> Result<CreateRoleCreateRole, AdaptiveError>
pub async fn list_teams(&self) -> Result<Vec<ListTeamsTeams>, AdaptiveError>
pub async fn create_team( &self, name: &str, key: Option<&str>, ) -> Result<CreateTeamCreateTeam, AdaptiveError>
pub async fn list_users(&self) -> Result<Vec<ListUsersUsers>, AdaptiveError>
pub async fn create_user( &self, name: &str, email: Option<&str>, teams: Vec<UserCreateTeamWithRole>, user_type: Option<UserType>, generate_api_key: Option<bool>, ) -> Result<CreateUserCreateUser, AdaptiveError>
pub async fn delete_user( &self, user: &str, ) -> Result<DeleteUserDeleteUser, AdaptiveError>
pub async fn add_team_member( &self, user: &str, team: &str, role: &str, ) -> Result<AddTeamMemberSetTeamMember, AdaptiveError>
pub async fn remove_team_member( &self, user: &str, team: &str, ) -> Result<RemoveTeamMemberRemoveTeamMember, AdaptiveError>
pub async fn get_recipe( &self, project: String, id_or_key: String, ) -> Result<Option<GetRecipeCustomRecipe>, AdaptiveError>
pub async fn get_grader( &self, id_or_key: &str, project: &str, ) -> Result<GetGraderGrader, AdaptiveError>
pub async fn get_dataset( &self, id_or_key: &str, project: &str, ) -> Result<Option<GetDatasetDataset>, AdaptiveError>
pub async fn get_model_config( &self, id_or_key: &str, ) -> Result<Option<GetModelConfigModel>, AdaptiveError>
pub fn base_url(&self) -> &Url
Sourcepub async fn upload_bytes(
&self,
data: &[u8],
content_type: &str,
) -> Result<String, AdaptiveError>
pub async fn upload_bytes( &self, data: &[u8], content_type: &str, ) -> Result<String, AdaptiveError>
Upload bytes using the chunked upload API and return the session_id. This can be used to link the uploaded file to an artifact.
Sourcepub async fn init_chunked_upload_with_content_type(
&self,
total_parts: u64,
content_type: &str,
) -> Result<String, AdaptiveError>
pub async fn init_chunked_upload_with_content_type( &self, total_parts: u64, content_type: &str, ) -> Result<String, AdaptiveError>
Initialize a chunked upload session.
Sourcepub async fn upload_part_simple(
&self,
session_id: &str,
part_number: u64,
data: Vec<u8>,
) -> Result<(), AdaptiveError>
pub async fn upload_part_simple( &self, session_id: &str, part_number: u64, data: Vec<u8>, ) -> Result<(), AdaptiveError>
Upload a single part of a chunked upload.
Sourcepub async fn abort_chunked_upload(
&self,
session_id: &str,
) -> Result<(), AdaptiveError>
pub async fn abort_chunked_upload( &self, session_id: &str, ) -> Result<(), AdaptiveError>
Abort a chunked upload session.
pub fn chunked_upload_dataset<'a, P: AsRef<Path> + Send + 'a>( &'a self, project: &'a str, name: &'a str, key: &'a str, dataset: P, ) -> Result<BoxStream<'a, Result<UploadEvent, AdaptiveError>>, AdaptiveError>
Sourcepub async fn download_file_to_path(
&self,
url: &str,
dest_path: &Path,
) -> Result<(), AdaptiveError>
pub async fn download_file_to_path( &self, url: &str, dest_path: &Path, ) -> Result<(), AdaptiveError>
Download a file from the given URL and write it to the specified path. The URL can be absolute or relative to the API base URL.